import React from 'react';
import { Color, Size } from '../../types';
type availableColor = Color.dark | Color.green | Color.blue;
interface CustomButtonProps extends React.ButtonHTMLAttributes<HTMLButtonElement> {
    color?: string;
    size: 'stable' | 'dynamic';
    isInverse?: boolean;
    selected?: boolean;
    mouseClick?: boolean;
}
interface ColorInterface {
    color: string | undefined;
    id: string;
}
interface SchemeType {
    style: {
        light: styleOptions;
        dark: styleOptions;
    };
    size: {
        s: sizeOptions;
        m: sizeOptions;
        l: sizeOptions;
    };
}
interface styleOptions {
    container: {
        backgroundColor: string;
        borderColor: string;
    };
    dividerColor: string;
    inputColor: {
        default: {
            fontColor: string;
            borderColor: string;
            placeholderColor: string;
            backgroundColor: string;
        };
        hover: {
            fontColor: string;
            borderColor: string;
            placeholderColor: string;
            backgroundColor: string;
        };
        focus: {
            fontColor: string;
            borderColor: string;
            placeholderColor: string;
            backgroundColor: string;
        };
        error: {
            borderColor: string;
        };
    };
    labelsColor: string;
    colorButton: {
        selectOutline: string;
        nonContrastObjectBorderColor: string;
    };
}
interface sizeOptions {
    sections: {
        paddingLeft: number;
        paddingRight: number;
    };
    sectionItem: {
        paddingTop: number;
        paddingBottom: number;
    };
    sectionWrapper: {
        gap: number;
        s: number;
        m: number;
    };
    inputroup: {
        gap: number;
    };
    colorInput: {
        fontSize: number;
        lineHeight: number;
        fontWeight: number | string;
        paddingLeft: number;
        paddingRight: number;
        paddingTop: number;
        paddingBottom: number;
    };
    inputColorLabel: {
        fontSize: number;
        lineHeight: number;
        fontWeight: number | string;
    };
    colorIndicator: {
        left: number;
    };
    label: {
        fontSize: number;
        lineHeight: number;
        fontWeight: number | string;
        gap: number;
        topPosition: {
            marginBottom: number;
        };
    };
    colorButton: {
        stable: {
            width: number;
            height: number;
        };
        dynamic: {
            width: number;
            height: number;
        };
    };
    paletteGrid: {
        gap: number;
    };
}
interface ColorPickerOptions {
    size?: Size;
    colorTheme?: availableColor;
    isInverse?: boolean;
    presetColors?: string[];
    recentColors?: string[];
    automaticColor?: string;
    activeColor?: string;
    enableEmptyColor?: boolean;
    enableCustomColor?: boolean;
    enableRecentColors?: boolean;
    enableAutomaticColor?: boolean;
    changeColor?: (color: string | undefined) => void;
}
interface ColorButtonOptions extends StateContextOptions {
    size: 'stable' | 'dynamic';
    color?: string;
    selected?: boolean;
    mouseClick?: boolean;
    borderForContrast?: boolean;
}
interface ColorInputOptions extends StateContextOptions {
    mouseClick?: boolean;
}
interface StateContextOptions {
    state: {
        dayTime: 'light' | 'dark';
        size: Size;
        styled: SchemeType;
    };
}
export type { CustomButtonProps, ColorPickerOptions, SchemeType, StateContextOptions, ColorButtonOptions, ColorInputOptions, ColorInterface, };
