import { InputHTMLAttributes } from 'react';
import { FontStyleTypeModel, ThemeTypesModel } from '../../Themes/theme_types';
import { Size, tooltipOptions } from '../../types';
type availableSize = Size.s | Size.m | Size.l;
type counterPosition = 'top-left' | 'top-right' | 'bottom-left' | 'bottom-right';
interface InputPropsType {
    value?: string;
    label?: string;
    ariaLabel?: string;
    labelPosition?: 'external' | 'internal';
    placeholder?: string;
    textAlign?: 'left' | 'right';
    size?: availableSize;
    tooltipIcon?: string;
    descriptionType?: 'text' | 'tooltip';
    description?: string;
    isTrimValue?: boolean;
    errorMessage?: string;
    isLengthLimited?: boolean;
    maxLength?: number;
    isRequired?: boolean;
    isInverse?: boolean;
    readOnly?: boolean;
    theme?: ThemeTypesModel;
    additionalAttributes?: InputHTMLAttributes<HTMLInputElement>;
    className?: string;
    lengthCounterPosition?: counterPosition;
    mask?: string;
    prefix?: string;
    suffix?: string;
    maskChar?: string;
    thousandSeparator?: 'comma' | 'point' | 'white space';
    decimalSeparator?: 'comma' | 'point';
    allowNegativeNumbers?: boolean;
    showMaskTyped?: boolean;
    errorState?: 'default' | 'focus out';
    isDisabled?: boolean;
    tooltipOptions?: tooltipOptions;
    isError?: boolean;
    valueChanged?: (val: string) => void;
    inputSubmitted?: (val: string) => void;
    onBlur?: () => void;
}
interface CounterSymbolsProps {
    isAlert: boolean;
}
interface InputInfoProps {
    position?: 'external' | 'internal';
}
interface ContainerProps {
    isDisabled: boolean;
    isError: boolean;
    styled: ModelView;
    dayTime: 'day' | 'night';
}
interface LabelProps {
    styled: ModelView;
    isRequired: boolean;
    dayTime: 'day' | 'night';
}
interface CounterSymbolsProps {
    styled: ModelView;
    isAlert: boolean;
    dayTime: 'day' | 'night';
}
interface DescriptionProps {
    styled: ModelView;
    dayTime: 'day' | 'night';
}
interface InputInfoProps {
    position?: 'external' | 'internal';
}
interface InputFieldProps {
    isFocused: boolean;
    textAlign: 'left' | 'right';
    styled: ModelView;
    isError: boolean;
    infoIconDisplay: boolean;
    sizeProp: availableSize | 'internal';
    dayTime: 'day' | 'night';
    isMaskPlaceholder: boolean;
}
interface RightIconProps {
    size: availableSize | 'internal';
    styled: ModelView;
    isDisabled: boolean;
    isError: boolean;
    dayTime: 'day' | 'night';
}
interface InnerLabelProps {
    styled: ModelView;
    dayTime: 'day' | 'night';
}
interface InputFooterProps {
    counterPosition: counterPosition;
}
interface inputViewParams {
    placeholderColor?: string;
    textColor?: string;
    borderColor?: string;
    backgroundColor?: string;
}
interface inputStates {
    default: inputViewParams;
    hover: inputViewParams;
    active: inputViewParams;
    readOnly: inputViewParams;
    errorDefault: inputViewParams;
    errorHover: inputViewParams;
}
interface sizeElementsParams {
    icon: {
        width: number;
        height: number;
    };
    input: {
        paddingTop: number;
        paddingLeft: number;
        paddingRight: number;
        paddingBottom: number;
    };
    font: FontStyleTypeModel;
}
interface dayMode {
    infoIcon: {
        default: {
            backgroundColor: string;
            iconColor: string;
        };
        hover: {
            backgroundColor: string;
            iconColor: string;
        };
        error: {
            iconColor: string;
        };
    };
    label: {
        color: string;
    };
    description: {
        color: string;
    };
    limitSize: {
        defaultColor: string;
        errorColor: string;
    };
    errorMessage: {
        color: string;
    };
    input: inputStates;
}
interface ModelView {
    style: {
        day: dayMode;
        night: dayMode;
    };
    size: {
        label: {
            font: FontStyleTypeModel;
        };
        description: {
            font: FontStyleTypeModel;
        };
        internal: {
            icon: {
                width: number;
                height: number;
            };
            input: {
                paddingTop: number;
                paddingLeft: number;
                paddingRight: number;
                paddingBottom: number;
            };
            font: FontStyleTypeModel;
        };
        s: sizeElementsParams;
        m: sizeElementsParams;
        l: sizeElementsParams;
    };
}
export type { InputPropsType, ContainerProps, LabelProps, CounterSymbolsProps, DescriptionProps, InputInfoProps, InputFieldProps, RightIconProps, InnerLabelProps, InputFooterProps, ModelView, };
