import { FontStyleTypeModel, ThemeTypesModel } from '../../Themes/theme_types';
import { Color, Size } from '../../types';
type availableColor = Color.green | Color.dark | Color.blue;
type availableSize = Size.s | Size.m;
interface TagValueType {
    title: string;
    initials?: string;
    imageUrl?: string;
    href?: string;
}
interface TagProps {
    tagValue: TagValueType;
    color?: availableColor;
    size?: availableSize;
    withLinkWrapper?: boolean;
    nested?: boolean;
    isRemovable?: boolean;
    withPicture?: boolean;
    removeIcon?: string;
    isError?: boolean;
    isDisabled?: boolean;
    isInverse?: boolean;
    avoidTab?: boolean;
    customClass?: string;
    theme?: ThemeTypesModel;
    tagChecked?: (value: string) => void;
    removed?: (value: string) => void;
}
interface ContainerPropType {
    color: availableColor;
    size: availableSize;
    isDisabled: boolean;
    nested: boolean;
    isError: boolean;
    focused: boolean;
    styled: ModelView;
    dayTime: 'day' | 'night';
}
interface UserPicAreaPropsType {
    size: availableSize;
    styled: ModelView;
}
interface InitialsPropType {
    size: availableSize;
    styled: ModelView;
}
interface TagTextPropType {
    compensation: 'textCompensated' | 'text';
    size: availableSize;
    styled: ModelView;
}
interface CloseButtonPropTyp {
    size: availableSize;
    styled: ModelView;
}
interface styleParams {
    backgroundColor: string;
    userPicBg: string;
    fontColor: string;
}
interface errorStates {
    default: styleParams;
    hover: styleParams;
}
interface states {
    default: styleParams;
    hover: styleParams;
    active: styleParams;
}
interface themeStates {
    day: {
        green: states;
        dark: states;
        blue: states;
    };
    night: {
        green: states;
        dark: states;
        blue: states;
    };
    error: errorStates;
}
interface ModelView {
    style: themeStates;
    size: {
        s: {
            userPicArea: {
                width: number;
                height: number;
            };
            userIcon: {
                padding: number;
            };
            initials: {
                font: FontStyleTypeModel;
            };
            container: object;
            text: {
                paddingTop: number;
                paddingRight: number;
                paddingBottom: number;
                paddingLeft: number;
            };
            textCompensated: {
                paddingLeft: number;
                paddingRight: number;
            };
            closeButton: {
                width: number;
                height: number;
                marginRight: number;
                marginLeft: number;
                svgWidth: number;
                svgHeight: number;
            };
            font: FontStyleTypeModel;
        };
        m: {
            userPicArea: {
                width: number;
                height: number;
            };
            userIcon: {
                padding: number;
            };
            initials: {
                font: FontStyleTypeModel;
            };
            text: {
                paddingTop: number;
                paddingRight: number;
                paddingBottom: number;
                paddingLeft: number;
            };
            textCompensated: {
                paddingLeft: number;
                paddingRight: number;
            };
            container: object;
            closeButton: {
                width: number;
                height: number;
                marginRight: number;
                marginLeft: number;
                svgWidth: number;
                svgHeight: number;
            };
            font: FontStyleTypeModel;
        };
    };
}
export type { TagValueType, TagProps, ContainerPropType, UserPicAreaPropsType, InitialsPropType, TagTextPropType, CloseButtonPropTyp, ModelView, };
